==> haskell-doctest-0.13.0-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-doctest.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: doctest
version: 0.13.0
id: doctest-0.13.0-3jaTavj2wHKHTer1GUnhkl
key: doctest-0.13.0-3jaTavj2wHKHTer1GUnhkl
license: MIT
copyright: (c) 2009-2017 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/doctest#readme
synopsis: Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.
    It is modeled after doctest for Python
    (<http://docs.python.org/library/doctest.html>).
    .
    Documentation is at
    <https://github.com/sol/doctest#readme>.
category: Testing
author: Simon Hengel <sol@typeful.net>
exposed: True
indefinite: False
exposed-modules:
    Test.DocTest
hidden-modules: Extract GhcUtil Interpreter Location Options
                PackageDBs Parse Paths_doctest Property Runner Runner.Example Run
                Util Sandbox Language.Haskell.GhciWrapper
abi: 5d5caa081f5189c2df63fc0ab0b73682
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/doctest-0.13.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/doctest-0.13.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/doctest-0.13.0
hs-libraries: HSdoctest-0.13.0-3jaTavj2wHKHTer1GUnhkl
depends:
    base-4.10.1.0 base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA ghc-8.2.2
    syb-0.7-3Lq8MQxmYP07qktjI1jxu0
    code-page-0.1.3-IgAXwLwH8aZ3hxp3qvXSZY deepseq-1.4.3.0
    directory-1.3.0.2 filepath-1.4.1.2 process-1.6.1.0
    ghc-paths-0.1.0.9-jtXMj34IrEDKFvgWnrf0G transformers-0.5.2.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA=b23a246a62afd271167dd1ea1b77583b
             ghc-8.2.2=a5b8ae61d881d53b10e55af3743c7814
             syb-0.7-3Lq8MQxmYP07qktjI1jxu0=f985ea42a9fa578e0f67572a93e19b5d
             code-page-0.1.3-IgAXwLwH8aZ3hxp3qvXSZY=684b55603f33f30e7e939e28620d2579
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             ghc-paths-0.1.0.9-jtXMj34IrEDKFvgWnrf0G=4d1f716168bb01b01d700e733eed3df6
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
haddock-interfaces: /usr/share/doc/haskell-doctest/html/doctest.haddock
haddock-html: /usr/share/doc/haskell-doctest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctest-0.13.0-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-doctest.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: doctest
version: 0.13.0
id: doctest-0.13.0-C94z3erOquy38PSFHZQSV1
key: doctest-0.13.0-C94z3erOquy38PSFHZQSV1
license: MIT
copyright: (c) 2009-2017 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/doctest#readme
synopsis: Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.
    It is modeled after doctest for Python
    (<http://docs.python.org/library/doctest.html>).
    .
    Documentation is at
    <https://github.com/sol/doctest#readme>.
category: Testing
author: Simon Hengel <sol@typeful.net>
exposed: True
indefinite: False
exposed-modules:
    Test.DocTest
hidden-modules: Extract GhcUtil Interpreter Location Options
                PackageDBs Parse Paths_doctest Property Runner Runner.Example Run
                Util Sandbox Language.Haskell.GhciWrapper
abi: dc0999892c2aa5870ad04b61738d1456
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/doctest-0.13.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/doctest-0.13.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/doctest-0.13.0
hs-libraries: HSdoctest-0.13.0-C94z3erOquy38PSFHZQSV1
depends:
    base-4.10.1.0 base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA ghc-8.2.2
    syb-0.7-3Lq8MQxmYP07qktjI1jxu0
    code-page-0.1.3-IgAXwLwH8aZ3hxp3qvXSZY deepseq-1.4.3.0
    directory-1.3.0.2 filepath-1.4.1.2 process-1.6.1.0
    ghc-paths-0.1.0.9-jtXMj34IrEDKFvgWnrf0G transformers-0.5.2.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA=b23a246a62afd271167dd1ea1b77583b
             ghc-8.2.2=a5b8ae61d881d53b10e55af3743c7814
             syb-0.7-3Lq8MQxmYP07qktjI1jxu0=f985ea42a9fa578e0f67572a93e19b5d
             code-page-0.1.3-IgAXwLwH8aZ3hxp3qvXSZY=684b55603f33f30e7e939e28620d2579
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             ghc-paths-0.1.0.9-jtXMj34IrEDKFvgWnrf0G=4d1f716168bb01b01d700e733eed3df6
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
haddock-interfaces: /usr/share/doc/haskell-doctest/html/doctest.haddock
haddock-html: /usr/share/doc/haskell-doctest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
